@@ -2,5 +2,6 @@ __version__ = '0.2'
 
 # make the following names available as part of the public API
 from .base import (API, LeverException, get_joined, LeverSyntaxError, jsonize,
-                   preprocess, postprocess, ModelBasedACL, ImpersonateMixin)
+                   preprocess, postprocess, ModelBasedACL, ImpersonateMixin,
+                   LeverServerError, LeverNotFound, LeverAccessDenied)
 from .acl import build_acl
